<p align="center">
<a href="https://travis-ci.org/spapanik/pygatherer"><img alt="Build" src="https://travis-ci.org/spapanik/pygatherer.svg?branch=master"></a>
<a href="https://coveralls.io/github/spapanik/pygatherer"><img alt="Coverage" src="https://coveralls.io/repos/github/spapanik/pygatherer/badge.svg?branch=master"></a>
<a href="https://github.com/spapanik/pygatherer/blob/master/LICENSE.txt"><img alt="License" src="https://img.shields.io/github/license/spapanik/pygatherer"></a>
<a href="https://pypi.org/project/pygatherer"><img alt="PyPI" src="https://img.shields.io/pypi/v/pygatherer"></a>
<a href="https://pepy.tech/project/pygatherer"><img alt="Downloads" src="https://pepy.tech/badge/pygatherer"></a>
<a href="https://github.com/psf/black"><img alt="Code style" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
</p>

Installation
------------

You can install pygatherer directly with pip:

    $ pip install pygatherer
